<?php

namespace EscapeWork\Manager\Http\Controllers;

use App\Library\AkkiIo\LaravelGoogleAnalytics\Facades\LaravelGoogleAnalytics;
use App\Library\AkkiIo\LaravelGoogleAnalytics\Period;
use Google\Analytics\Data\V1beta\Filter\StringFilter\MatchType;
use Google\Analytics\Data\V1beta\MetricAggregation;
use Google\Analytics\Data\V1beta\Filter\NumericFilter\Operation;

class HomeController extends Controller
{

    public function index()
    {

        if( config("laravel-google-analytics.property_id") ){

            $visitorsByDay = LaravelGoogleAnalytics::dateRanges(Period::days(30))
                ->metrics('sessions', 'screenPageViews')
                ->dimensions('date')
                ->get();

            $dates = $visitorsByDay->table;
            $sortArray = array();

            foreach($dates as $date){
                foreach($date as $key=>$value){
                    if(!isset($sortArray[$key])){
                        $sortArray[$key] = array();
                    }
                    $sortArray[$key][] = $value;
                }
            }

            array_multisort($sortArray['date'],SORT_ASC,$dates);

            $visitorsByDay = $dates;

            $visitorsAndPageviews = LaravelGoogleAnalytics::dateRanges(Period::days(30), Period::days(60))
                ->metrics('sessions', 'screenPageViews')
                ->get();

            $browsers = LaravelGoogleAnalytics::dateRanges(Period::days(30))
                ->metrics('sessions')
                ->dimensions('deviceCategory')
                ->get();

            $mostVisited = LaravelGoogleAnalytics::getMostViewsByPage(Period::days(30), $count = 20);

            $averageTime = LaravelGoogleAnalytics::dateRanges(Period::days(30))
                ->metrics('averageSessionDuration')
                ->get();

            $averageTime = (object) $this->secondsToTime( $averageTime->table[0]['averageSessionDuration']) ;

        }

        return view(config('manager.views.home'),
            [
                'visitorsByDay' => isset( $visitorsByDay ) ? $visitorsByDay : null,
                'visitorsAndPageviews' => isset($visitorsAndPageviews ) ? $visitorsAndPageviews : null,
                'browsers' => isset( $browsers ) ? $browsers : null,
                'mostVisited' => isset( $mostVisited ) ? $mostVisited : null,
                'averageTime' => isset( $averageTime ) ? $averageTime : null
            ]);
    }

    function secondsToTime($inputSeconds) {

        $secondsInAMinute = 60;
        $secondsInAnHour  = 60 * $secondsInAMinute;
        $secondsInADay    = 24 * $secondsInAnHour;

        // extract days
        $days = floor($inputSeconds / $secondsInADay);

        // extract hours
        $hourSeconds = $inputSeconds % $secondsInADay;
        $hours = floor($hourSeconds / $secondsInAnHour);

        // extract minutes
        $minuteSeconds = $hourSeconds % $secondsInAnHour;
        $minutes = floor($minuteSeconds / $secondsInAMinute);

        // extract the remaining seconds
        $remainingSeconds = $minuteSeconds % $secondsInAMinute;
        $seconds = ceil($remainingSeconds);

        // return the final array
        $obj = array(
            'd' => (int) $days,
            'h' => str_pad($hours,2,'0', STR_PAD_LEFT),
            'm' => str_pad($minutes,2,'0', STR_PAD_LEFT),
            's' => str_pad($seconds,2,'0', STR_PAD_LEFT)
        );

        return $obj;
    }

}
